# Contribution Guidelines

:tada: **First off, thank you for considering contributing to our project!**
:tada:

This is a community-driven project, so it's people like you that make it useful
and successful. These are some of the many ways to contribute:

- 🐛, 🎊 Submitting bug reports and feature requests.

## Ground Rules

The goal is to maintain a diverse community that's pleasant for everyone.
**Please be considerate and respectful of others**. Everyone must abide by our
[Code of Conduct][docs/code-of-conduct.md] and we encourage all to read it
carefully.

### Maintainers Guide

See the [maintenance guide here](docs/development-guide.md).
